@@ -6,20 +6,17 @@
 #' messages with cli formatting, including inline styling,
 #' pluralization and glue substitutions.
 #'
-#' @param message It is formatted via a call to [cli_bullets()].
-#' @param ... Passed to [rlang::abort()], [rlang::warn()] or
-#'   [rlang::inform()].
-#' @param .envir Environment to evaluate the glue expressions in.
+#' @details
 #'
-#' @export
-#' @examples
-#' \dontrun{
+#' ```{asciicast cli-abort}
 #' n <- "boo"
 #' cli_abort(c(
 #'         "{.var n} must be a numeric vector",
 #'   "x" = "You've supplied a {.cls {class(n)}} vector."
 #' ))
+#' ```
 #'
+#' ```{asciicast cli-abort-2}
 #' len <- 26
 #' idx <- 100
 #' cli_abort(c(
@@ -27,23 +24,48 @@
 #'   "i" = "There {?is/are} {len} element{?s}.",
 #'   "x" = "You've tried to subset element {idx}."
 #' ))
-#' }
+#' ```
+#'
+#' @param message It is formatted via a call to [cli_bullets()].
+#' @param ... Passed to [rlang::abort()], [rlang::warn()] or
+#'   [rlang::inform()].
+#' @param .envir Environment to evaluate the glue expressions in.
+#'
+#' @export
 
 cli_abort <- function(message, ..., .envir = parent.frame()) {
-  rlang::abort(format_error(message, .envir = .envir), ...)
+  message[] <- vcapply(message, format_inline, .envir = .envir)
+  escaped_message <- cli_escape(message)
+  rlang::abort(
+    format_error(escaped_message, .envir = .envir),
+    cli_bullets = message,
+    ...
+  )
 }
 
 #' @rdname cli_abort
 #' @export
 
 cli_warn <- function(message, ..., .envir = parent.frame()) {
-  rlang::warn(format_warning(message, .envir = .envir), ...)
+  message[] <- vcapply(message, format_inline, .envir = .envir)
+  escaped_message <- cli_escape(message)
+  rlang::warn(
+    format_warning(escaped_message, .envir = .envir),
+    cli_bullets = message,
+    ...
+  )
 }
 
 #' @rdname cli_abort
 #' @export
 
 cli_inform <- function(message, ..., .envir = parent.frame()) {
+  message[] <- vcapply(message, format_inline, .envir = .envir)
+  escaped_message <- cli_escape(message)
   cli_status("", "", "")
-  rlang::inform(format_message(message, .envir = .envir), ...)
+  rlang::inform(
+    format_message(message, .envir = .envir),
+    cli_bullets = message,
+    ...
+  )
 }
